import { ProjectConfiguration, ProjectsConfigurations } from '../../config/workspace-json-project-json';
import { NxJsonConfiguration } from '../../config/nx-json';
import { ProjectGraphExternalNode } from '../../config/project-graph';
import { ConfigurationSourceMaps } from './project-configuration-utils';
import { LoadedNxPlugin } from '../../utils/nx-plugin';
/**
 * Walks the workspace directory to create the `projectFileMap`, `ProjectConfigurations` and `allWorkspaceFiles`
 * @throws
 * @param workspaceRoot
 * @param nxJson
 */
export declare function retrieveWorkspaceFiles(workspaceRoot: string, nxJson: NxJsonConfiguration): Promise<{
    allWorkspaceFiles: import("../../config/project-graph").FileData[];
    fileMap: {
        projectFileMap: ProjectFiles;
        nonProjectFiles: import("../../native").FileData[];
    };
    projectConfigurations: ProjectsConfigurations;
    externalNodes: Record<string, ProjectGraphExternalNode>;
    sourceMaps: ConfigurationSourceMaps;
    rustReferences: import("../../native").NxWorkspaceFilesExternals;
}>;
/**
 * Walk through the workspace and return `ProjectConfigurations`. Only use this if the projectFileMap is not needed.
 *
 * @param workspaceRoot
 * @param nxJson
 */
export declare function retrieveProjectConfigurations(workspaceRoot: string, nxJson: NxJsonConfiguration): Promise<{
    externalNodes: Record<string, ProjectGraphExternalNode>;
    projectNodes: Record<string, ProjectConfiguration>;
    sourceMaps: ConfigurationSourceMaps;
}>;
export declare function retrieveProjectConfigurationsWithAngularProjects(workspaceRoot: string, nxJson: NxJsonConfiguration): Promise<{
    externalNodes: Record<string, ProjectGraphExternalNode>;
    projectNodes: Record<string, ProjectConfiguration>;
    sourceMaps: ConfigurationSourceMaps;
}>;
export declare function retrieveProjectConfigurationPaths(root: string, plugins: LoadedNxPlugin[]): string[];
export declare function retrieveProjectConfigurationsWithoutPluginInference(root: string): Promise<Record<string, ProjectConfiguration>>;
export declare function createProjectConfigurations(workspaceRoot: string, nxJson: NxJsonConfiguration, configFiles: string[], plugins: LoadedNxPlugin[]): Promise<{
    projects: Record<string, ProjectConfiguration>;
    externalNodes: Record<string, ProjectGraphExternalNode>;
    rootMap: Record<string, string>;
    sourceMaps: ConfigurationSourceMaps;
}>;
export declare function configurationGlobs(plugins: LoadedNxPlugin[]): string[];
